Stan Math Library: stan/math/prim/mat/prob/categorical_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
categorical_log.hpp File Reference
`#include <boost/random/uniform_01.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/mat/err/check_simplex.hpp>`
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/mat/fun/sum.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/scal/meta/is_constant_struct.hpp>`
`#include <cmath>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_prob >
boost::math::tools::promote_args< T_prob >::type | stan::math::categorical_log (int n, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)
template<typename T_prob >
boost::math::tools::promote_args< T_prob >::type | stan::math::categorical_log (const typename math::index_type< Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > >::type n, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)
template<bool propto, typename T_prob >
boost::math::tools::promote_args< T_prob >::type | stan::math::categorical_log (const std::vector< int > &ns, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)
template<typename T_prob >
boost::math::tools::promote_args< T_prob >::type | stan::math::categorical_log (const std::vector< int > &ns, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)

[ Stan Home Page ] © 2011–2016, Stan Development Team.